@@ -4,7 +4,7 @@
  * Gnome Crystal
  * cleavage.h 
  *
- * Copyright (C) 2001-2002
+ * Copyright (C) 2001-2003
  *
  * Developed by Jean Brfort <jean.brefort@ac-dijon.fr>
  *
@@ -27,29 +27,19 @@
 #ifndef GCRYSTAL_CLEAVAGE_H
 #define GCRYSTAL_CLEAVAGE_H
 
-#include <gnome-xml/parser.h>
+#include <crystalviewer/crystalcleavage.h>
+#include <libxml/parser.h>
 #include <list>
 
-class gcCleavage
+using namespace gcu;
+
+class gcCleavage: public CrystalCleavage
 {
 public:
 	gcCleavage();
-	gcCleavage(gcCleavage& ccClivage) ;
 	virtual ~gcCleavage();
 
-	int& Planes() {return m_nPlanes ;}
-	int &h() {return m_nh ;}
-	int &k() {return m_nk ;}
-	int &l() {return m_nl ;}
-	gcCleavage& operator=(gcCleavage&) ;
-	bool operator==(gcCleavage&) ;
-	xmlNodePtr Save(xmlDocPtr xml);
-	bool Load(xmlNodePtr node);
-	
-private :
-	int m_nh, m_nk, m_nl, m_nPlanes ;
+	bool LoadOld(xmlNodePtr node);
 };
 
-typedef std::list<gcCleavage*> gcCleavageList;
-
 #endif //GCRYSTAL_CLEAVAGE_H
